# -------------------------------------------------------------------------------
# (c) 2019-2022 Siemens AG
# All Rights Reserved.
# Author: thomas.graf@siemens.com
#
# Licensed under the MIT license.
# SPDX-License-Identifier: MIT
# -------------------------------------------------------------------------------

__version__ = (1, 2, 0)

from .sw360_api import SW360  # noqa: F401
from .sw360error import SW360Error  # noqa: F401
from .sw360oauth2 import SW360OAuth2  # noqa: F401
